# Chapter 2: Programming Survival Guide

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 2 章：编程生存指南 (Programming Survival Guide)](../../zh/textbook/02_programming.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch02_programming.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch02_programming.py)
  - Extended example: [examples/17_readme_demo.py](https://github.com/akfamily/akquant/blob/main/examples/17_readme_demo.py)
  - Guide: [Python Basics Guide](../guide/python_basics.md)
